==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PieSliceOthersContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieSliceOthersContextDescription } from "./PieSliceOthersContextDescription";
/**
 * @hidden
 */
export let PieSliceOthersContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieSliceOthersContextDescriptionMetadata extends Base {
        static b(a) {
            if (PieSliceOthersContextDescriptionMetadata.a == null) {
                PieSliceOthersContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieSliceOthersContextDescriptionMetadata.c(PieSliceOthersContextDescriptionMetadata.a);
            }
            if (a.k(PieSliceOthersContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(PieSliceOthersContextDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            PieSliceOthersContextDescriptionMetadata.b(a);
            a.ad("PieSliceOthersContext", () => new PieSliceOthersContextDescription());
            a.ac("PieSliceOthersContext", PieSliceOthersContextDescriptionMetadata.a);
        }
    }
    PieSliceOthersContextDescriptionMetadata.$t = /*@__PURE__*/ markType(PieSliceOthersContextDescriptionMetadata, 'PieSliceOthersContextDescriptionMetadata');
    PieSliceOthersContextDescriptionMetadata.a = null;
    return PieSliceOthersContextDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/PieSliceOthersContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PieSliceOthersContextDescription } from "./PieSliceOthersContextDescription";
/**
 * @hidden
 */
export let PieSliceOthersContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class PieSliceOthersContextDescriptionMetadata extends Base {
        static b(a) {
            if (PieSliceOthersContextDescriptionMetadata.a == null) {
                PieSliceOthersContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PieSliceOthersContextDescriptionMetadata.c(PieSliceOthersContextDescriptionMetadata.a);
            }
            if (a.k(PieSliceOthersContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(PieSliceOthersContextDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            PieSliceOthersContextDescriptionMetadata.b(a);
            a.ae("PieSliceOthersContext", () => new PieSliceOthersContextDescription());
            a.ad("PieSliceOthersContext", PieSliceOthersContextDescriptionMetadata.a);
        }
    }
    PieSliceOthersContextDescriptionMetadata.$t = /*@__PURE__*/ markType(PieSliceOthersContextDescriptionMetadata, 'PieSliceOthersContextDescriptionMetadata');
    PieSliceOthersContextDescriptionMetadata.a = null;
    return PieSliceOthersContextDescriptionMetadata;
})();
